SVMTransactionExecutionBudget

Struct SVMTransactionExecutionBudget 

pub struct SVMTransactionExecutionBudget {
    pub compute_unit_limit: u64,
    pub max_instruction_stack_depth: usize,
    pub max_instruction_trace_length: usize,
    pub sha256_max_slices: u64,
    pub max_call_depth: usize,
    pub stack_frame_size: usize,
    pub heap_size: u32,
}

Fields

compute_unit_limit: u64

Number of compute units that a transaction or individual instruction is allowed to consume. Compute units are consumed by program execution, resources they use, etc…

max_instruction_stack_depth: usize

Maximum program instruction invocation stack depth. Invocation stack depth starts at 1 for transaction instructions and the stack depth is incremented each time a program invokes an instruction and decremented when a program returns.

max_instruction_trace_length: usize

Maximum cross-program invocation and instructions per transaction

sha256_max_slices: u64

Maximum number of slices hashed per syscall

max_call_depth: usize

Maximum SBF to BPF call depth

stack_frame_size: usize

Size of a stack frame in bytes, must match the size specified in the LLVM SBF backend

heap_size: u32

program heap region size, default: trezoa_program_entrypoint::HEAP_LENGTH

Implementations